@@ -1,22 +1,8 @@
-/********************************************************************
-Copyright 2015  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2015 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #include "plasmashell.h"
 #include "event_queue.h"
 #include "output.h"
@@ -30,14 +16,14 @@ namespace KWayland
 namespace Client
 {
 
-class PlasmaShell::Private
+class Q_DECL_HIDDEN PlasmaShell::Private
 {
 public:
     WaylandPointer<org_kde_plasma_shell, org_kde_plasma_shell_destroy> shell;
     EventQueue *queue = nullptr;
 };
 
-class PlasmaShellSurface::Private
+class Q_DECL_HIDDEN PlasmaShellSurface::Private
 {
 public:
     Private(PlasmaShellSurface *q);
@@ -78,7 +64,7 @@ void PlasmaShell::destroy()
     if (!d->shell) {
         return;
     }
-    emit interfaceAboutToBeDestroyed();
+    Q_EMIT interfaceAboutToBeDestroyed();
     d->shell.destroy();
 }
 
@@ -87,7 +73,7 @@ void PlasmaShell::release()
     if (!d->shell) {
         return;
     }
-    emit interfaceAboutToBeReleased();
+    Q_EMIT interfaceAboutToBeReleased();
     d->shell.release();
 }
 
@@ -191,14 +177,14 @@ void PlasmaShellSurface::Private::autoHidingPanelHiddenCallback(void *data, org_
 {
     auto p = reinterpret_cast<PlasmaShellSurface::Private*>(data);
     Q_ASSERT(p->surface == org_kde_plasma_surface);
-    emit p->q->autoHidePanelHidden();
+    Q_EMIT p->q->autoHidePanelHidden();
 }
 
 void PlasmaShellSurface::Private::autoHidingPanelShownCallback(void *data, org_kde_plasma_surface *org_kde_plasma_surface)
 {
     auto p = reinterpret_cast<PlasmaShellSurface::Private*>(data);
     Q_ASSERT(p->surface == org_kde_plasma_surface);
-    emit p->q->autoHidePanelShown();
+    Q_EMIT p->q->autoHidePanelShown();
 }
 
 PlasmaShellSurface::PlasmaShellSurface(QObject *parent)
@@ -280,6 +266,14 @@ void PlasmaShellSurface::setRole(PlasmaShellSurface::Role role)
     case Role::ToolTip:
         wlRole = ORG_KDE_PLASMA_SURFACE_ROLE_TOOLTIP;
         break;
+    case Role::CriticalNotification:
+        if (wl_proxy_get_version(d->surface) < ORG_KDE_PLASMA_SURFACE_ROLE_CRITICALNOTIFICATION_SINCE_VERSION) {
+            // Fall back to generic notification type if not supported
+            wlRole = ORG_KDE_PLASMA_SURFACE_ROLE_NOTIFICATION;
+        } else {
+            wlRole = ORG_KDE_PLASMA_SURFACE_ROLE_CRITICALNOTIFICATION;
+        }
+        break;
     default:
         Q_UNREACHABLE();
         break;
@@ -322,6 +316,11 @@ void PlasmaShellSurface::setSkipTaskbar(bool skip)
     org_kde_plasma_surface_set_skip_taskbar(d->surface, skip);
 }
 
+void PlasmaShellSurface::setSkipSwitcher(bool skip)
+{
+    org_kde_plasma_surface_set_skip_switcher(d->surface, skip);
+}
+
 void PlasmaShellSurface::requestHideAutoHidingPanel()
 {
     org_kde_plasma_surface_panel_auto_hide_hide(d->surface);
