@@ -171,7 +171,7 @@ static const QMap<Registry::Interface, SuppertedInterfaceData> s_interfaces = {
         &Registry::plasmaVirtualDesktopManagementRemoved
     }},
     {Registry::Interface::PlasmaWindowManagement, {
-        13,
+        14,
         QByteArrayLiteral("org_kde_plasma_window_management"),
         &org_kde_plasma_window_management_interface,
         &Registry::plasmaWindowManagementAnnounced,
@@ -452,7 +452,7 @@ void Registry::release()
 
 void Registry::destroy()
 {
-    emit registryDestroyed();
+    Q_EMIT registryDestroyed();
     d->registry.destroy();
     d->callback.destroy();
 }
@@ -536,7 +536,7 @@ void Registry::Private::globalSync(void* data, wl_callback* callback, uint32_t s
 
 void Registry::Private::handleGlobalSync()
 {
-    emit q->interfacesAnnounced();
+    Q_EMIT q->interfacesAnnounced();
 }
 
 namespace {
@@ -554,7 +554,7 @@ static Registry::Interface nameToInterface(const char *interface)
 void Registry::Private::handleAnnounce(uint32_t name, const char *interface, uint32_t version)
 {
     Interface i = nameToInterface(interface);
-    emit q->interfaceAnnounced(QByteArray(interface), name, version);
+    Q_EMIT q->interfaceAnnounced(QByteArray(interface), name, version);
     if (i == Interface::Unknown) {
         qCDebug(KWAYLAND_CLIENT) << "Unknown interface announced: " << interface << "/" << name << "/" << version;
         return;
@@ -563,7 +563,7 @@ void Registry::Private::handleAnnounce(uint32_t name, const char *interface, uin
     m_interfaces.append({i, name, version});
     auto it = s_interfaces.constFind(i);
     if (it != s_interfaces.end()) {
-        emit (q->*it.value().announcedSignal)(name, version);
+        Q_EMIT (q->*it.value().announcedSignal)(name, version);
     }
 }
 
@@ -579,10 +579,10 @@ void Registry::Private::handleRemove(uint32_t name)
         m_interfaces.erase(it);
         auto sit = s_interfaces.find(data.interface);
         if (sit != s_interfaces.end()) {
-            emit (q->*sit.value().removedSignal)(data.name);
+            Q_EMIT (q->*sit.value().removedSignal)(data.name);
         }
     }
-    emit q->interfaceRemoved(name);
+    Q_EMIT q->interfaceRemoved(name);
 }
 
 bool Registry::Private::hasInterface(Registry::Interface interface) const
@@ -702,7 +702,7 @@ T *Registry::Private::create(quint32 name, quint32 version, QObject *parent, WL
     QObject::connect(q, &Registry::interfaceRemoved, t,
         [t, name] (quint32 removed) {
             if (name == removed) {
-                emit t->removed();
+                Q_EMIT t->removed();
             }
         }
     );
