@@ -1,27 +1,12 @@
-/********************************************************************
-Copyright 2013  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2013 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #include "shm_pool.h"
 #include "event_queue.h"
-#include "buffer.h"
 #include "buffer_p.h"
-#include "logging_p.h"
+#include "logging.h"
 #include "wayland_pointer_p.h"
 // Qt
 #include <QDebug>
@@ -162,7 +147,7 @@ bool ShmPool::Private::resizePool(int32_t newSize)
         qCDebug(KWAYLAND_CLIENT) << "Resizing Shm pool failed";
         return false;
     }
-    emit q->poolResized();
+    Q_EMIT q->poolResized();
     return true;
 }
 
